summaryrefslogtreecommitdiffstats
path: root/ash/shell_delegate.h
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-02-03 23:51:27 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-02-03 23:51:27 +0000
commiteec097142c4b7d09ff01a03e2e2117f290d68cfc (patch)
treee31de7ef3985e92eabbfb65ed10dac797c0ba0b6 /ash/shell_delegate.h
parent3b3af9753ec5dd2796df0555900515bb8ba0c613 (diff)
downloadchromium_src-eec097142c4b7d09ff01a03e2e2117f290d68cfc.zip
chromium_src-eec097142c4b7d09ff01a03e2e2117f290d68cfc.tar.gz
chromium_src-eec097142c4b7d09ff01a03e2e2117f290d68cfc.tar.bz2
Renames LauncherID, LauncherItem and LauncherItems...
to ShelfID, ShelfItem and ShelfItems. BUG=248353 TEST=None R=jamescook@chromium.org,harrym@chromium.org Review URL: https://codereview.chromium.org/152223002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@248619 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/shell_delegate.h')
-rw-r--r--ash/shell_delegate.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/ash/shell_delegate.h b/ash/shell_delegate.h
index 8ca36dc2..7bb4ebe 100644
--- a/ash/shell_delegate.h
+++ b/ash/shell_delegate.h
@@ -53,7 +53,7 @@ class ShelfItemDelegate;
class ShelfModel;
class SystemTrayDelegate;
class UserWallpaperDelegate;
-struct LauncherItem;
+struct ShelfItem;
// Delegate of the Shell.
class ASH_EXPORT ShellDelegate {
@@ -128,11 +128,11 @@ class ASH_EXPORT ShellDelegate {
// Creates a menu model of the context for the |root_window|.
// When a ContextMenu is used for an item created by ShelfWindowWatcher,
// passes its ShelfItemDelegate and LauncherItem.
virtual ui::MenuModel* CreateContextMenu(
aura::Window* root_window,
ash::ShelfItemDelegate* item_delegate,
- ash::LauncherItem* item) = 0;
+ ash::ShelfItem* item) = 0;
// Creates a root window host factory. Shell takes ownership of the returned
// value.
@@ -128,11 +128,11 @@ class ASH_EXPORT ShellDelegate {
// Creates a menu model of the context for the |root_window|.
// When a ContextMenu is used for an item created by ShelfWindowWatcher,
- // passes its ShelfItemDelegate and LauncherItem.
+ // passes its ShelfItemDelegate and ShelfItem.
virtual ui::MenuModel* CreateContextMenu(
aura::Window* root_window,